"""
Test Poi CSV export.
"""

import io
import csv

from retrans.poi import testing


class TestPoiCSVExport(testing.RetransPoiTestCase):
    """
    Test Poi CSV export.
    """

    def test_export_empty_issue(self):
        """
        An empty issue can be exported to CSV.
        """
        tracker = self.layer['tracker']
        self.setUpBrowser()
        self.browser.open(tracker.absolute_url())
        self.browser.getLink('All pending issues').click()
        self.browser.getLink('Export CSV').click()

        raw_csv = self.browser.contents
        reader = csv.DictReader(io.BytesIO(raw_csv))
        rows = list(reader)

        self.assertEquals(
            len(rows), 1,
            'Wrong number of exported CSV rows')
        row = rows[0]
        self.assertIn(
            'Complexity', row,
            'Exported CSV missing custom issue field')
        self.assertEqual(
            row['Complexity'], '',
            'Exported CSV wrong custom issue field value')

        self.assertNotIn(
            'Software Engineer Time', row,
            'Exported CSV includes ambiguous custom issue field label')
        self.assertIn(
            'Software Engineer - Estimated', row,
            'Exported CSV missing custom issue field')
        self.assertIn(
            'System Engineer - Actual', row,
            'Exported CSV missing custom issue field')

        self.assertIn(
            'Operations ROI - Estimated', row,
            'Exported CSV missing custom issue field')
